module.exports = {
	"39.0.2171.65": [
		"0.20.0",
		"0.20.1",
		"0.20.2",
		"0.20.3",
		"0.20.4",
		"0.20.5",
		"0.20.6",
		"0.20.7",
		"0.20.8"
	],
	"40.0.2214.91": [
		"0.21.0",
		"0.21.1",
		"0.21.2"
	],
	"41.0.2272.76": [
		"0.21.3",
		"0.22.1",
		"0.22.2",
		"0.22.3",
		"0.23.0",
		"0.24.0"
	],
	"42.0.2311.107": [
		"0.25.0",
		"0.25.1",
		"0.25.2",
		"0.25.3",
		"0.26.0",
		"0.26.1",
		"0.27.0",
		"0.27.1"
	],
	"43.0.2357.65": [
		"0.27.2",
		"0.27.3",
		"0.28.0",
		"0.28.1",
		"0.28.2",
		"0.28.3",
		"0.29.1",
		"0.29.2"
	],
	"44.0.2403.125": [
		"0.30.4",
		"0.31.0"
	],
	"45.0.2454.85": [
		"0.31.2",
		"0.32.2",
		"0.32.3",
		"0.33.0",
		"0.33.1",
		"0.33.2",
		"0.33.3",
		"0.33.4",
		"0.33.6",
		"0.33.7",
		"0.33.8",
		"0.33.9",
		"0.34.0",
		"0.34.1",
		"0.34.2",
		"0.34.3",
		"0.34.4",
		"0.35.1",
		"0.35.2",
		"0.35.3",
		"0.35.4",
		"0.35.5"
	],
	"47.0.2526.73": [
		"0.36.0",
		"0.36.2",
		"0.36.3",
		"0.36.4"
	],
	"47.0.2526.110": [
		"0.36.5",
		"0.36.6",
		"0.36.7",
		"0.36.8",
		"0.36.9",
		"0.36.10",
		"0.36.11",
		"0.36.12"
	],
	"49.0.2623.75": [
		"0.37.0",
		"0.37.1",
		"0.37.3",
		"0.37.4",
		"0.37.5",
		"0.37.6",
		"0.37.7",
		"0.37.8",
		"1.0.0",
		"1.0.1",
		"1.0.2"
	],
	"50.0.2661.102": [
		"1.1.0",
		"1.1.1",
		"1.1.2",
		"1.1.3"
	],
	"51.0.2704.63": [
		"1.2.0",
		"1.2.1"
	],
	"51.0.2704.84": [
		"1.2.2",
		"1.2.3"
	],
	"51.0.2704.103": [
		"1.2.4",
		"1.2.5"
	],
	"51.0.2704.106": [
		"1.2.6",
		"1.2.7",
		"1.2.8"
	],
	"52.0.2743.82": [
		"1.3.0",
		"1.3.1",
		"1.3.2",
		"1.3.3",
		"1.3.4",
		"1.3.5",
		"1.3.6",
		"1.3.7",
		"1.3.9",
		"1.3.10",
		"1.3.13",
		"1.3.14",
		"1.3.15"
	],
	"53.0.2785.113": [
		"1.4.0",
		"1.4.1",
		"1.4.2",
		"1.4.3",
		"1.4.4",
		"1.4.5"
	],
	"53.0.2785.143": [
		"1.4.6",
		"1.4.7",
		"1.4.8",
		"1.4.10",
		"1.4.11",
		"1.4.13",
		"1.4.14",
		"1.4.15",
		"1.4.16"
	],
	"54.0.2840.51": [
		"1.4.12"
	],
	"54.0.2840.101": [
		"1.5.0",
		"1.5.1"
	],
	"56.0.2924.87": [
		"1.6.0",
		"1.6.1",
		"1.6.2",
		"1.6.3",
		"1.6.4",
		"1.6.5",
		"1.6.6",
		"1.6.7",
		"1.6.8",
		"1.6.9",
		"1.6.10",
		"1.6.11",
		"1.6.12",
		"1.6.13",
		"1.6.14",
		"1.6.15",
		"1.6.16",
		"1.6.17",
		"1.6.18"
	],
	"58.0.3029.110": [
		"1.7.0",
		"1.7.1",
		"1.7.2",
		"1.7.3",
		"1.7.4",
		"1.7.5",
		"1.7.6",
		"1.7.7",
		"1.7.8",
		"1.7.9",
		"1.7.10",
		"1.7.11",
		"1.7.12",
		"1.7.13",
		"1.7.14",
		"1.7.15",
		"1.7.16"
	],
	"59.0.3071.115": [
		"1.8.0",
		"1.8.1",
		"1.8.2-beta.1",
		"1.8.2-beta.2",
		"1.8.2-beta.3",
		"1.8.2-beta.4",
		"1.8.2-beta.5",
		"1.8.2",
		"1.8.3",
		"1.8.4",
		"1.8.5",
		"1.8.6",
		"1.8.7",
		"1.8.8"
	],
	"61.0.3163.100": [
		"2.0.0-beta.1",
		"2.0.0-beta.2",
		"2.0.0-beta.3",
		"2.0.0-beta.4",
		"2.0.0-beta.5",
		"2.0.0-beta.6",
		"2.0.0-beta.7",
		"2.0.0-beta.8",
		"2.0.0",
		"2.0.1",
		"2.0.2",
		"2.0.3",
		"2.0.4",
		"2.0.5",
		"2.0.6",
		"2.0.7",
		"2.0.8-nightly.20180819",
		"2.0.8-nightly.20180820",
		"2.0.8",
		"2.0.9",
		"2.0.10",
		"2.0.11",
		"2.0.12",
		"2.0.13",
		"2.0.14",
		"2.0.15",
		"2.0.16",
		"2.0.17",
		"2.0.18",
		"2.1.0-unsupported.20180809"
	],
	"66.0.3359.181": [
		"3.0.0-beta.1",
		"3.0.0-beta.2",
		"3.0.0-beta.3",
		"3.0.0-beta.4",
		"3.0.0-beta.5",
		"3.0.0-beta.6",
		"3.0.0-beta.7",
		"3.0.0-beta.8",
		"3.0.0-beta.9",
		"3.0.0-beta.10",
		"3.0.0-beta.11",
		"3.0.0-beta.12",
		"3.0.0-beta.13",
		"3.0.0-nightly.20180818",
		"3.0.0-nightly.20180821",
		"3.0.0-nightly.20180823",
		"3.0.0-nightly.20180904",
		"3.0.0",
		"3.0.1",
		"3.0.2",
		"3.0.3",
		"3.0.4",
		"3.0.5",
		"3.0.6",
		"3.0.7",
		"3.0.8",
		"3.0.9",
		"3.0.10",
		"3.0.11",
		"3.0.12",
		"3.0.13",
		"3.0.14",
		"3.0.15",
		"3.0.16",
		"3.1.0-beta.1",
		"3.1.0-beta.2",
		"3.1.0-beta.3",
		"3.1.0-beta.4",
		"3.1.0-beta.5",
		"3.1.0",
		"3.1.1",
		"3.1.2",
		"3.1.3",
		"3.1.4",
		"3.1.5",
		"3.1.6",
		"3.1.7",
		"3.1.8",
		"3.1.9",
		"3.1.10",
		"3.1.11",
		"3.1.12",
		"3.1.13",
		"4.0.0-nightly.20180817",
		"4.0.0-nightly.20180819",
		"4.0.0-nightly.20180821"
	],
	"69.0.3497.106": [
		"4.0.0-beta.1",
		"4.0.0-beta.2",
		"4.0.0-beta.3",
		"4.0.0-beta.4",
		"4.0.0-beta.5",
		"4.0.0-beta.6",
		"4.0.0-beta.7",
		"4.0.0-beta.8",
		"4.0.0-beta.9",
		"4.0.0-beta.10",
		"4.0.0-beta.11",
		"4.0.0-nightly.20181010",
		"4.0.0",
		"4.0.1",
		"4.0.2",
		"4.0.3",
		"4.0.4",
		"4.0.5",
		"4.0.6"
	],
	"67.0.3396.99": [
		"4.0.0-nightly.20180929"
	],
	"68.0.3440.128": [
		"4.0.0-nightly.20181006"
	],
	"69.0.3497.128": [
		"4.0.7",
		"4.0.8",
		"4.1.0",
		"4.1.1",
		"4.1.2",
		"4.1.3",
		"4.1.4",
		"4.1.5",
		"4.2.0",
		"4.2.1",
		"4.2.2",
		"4.2.3",
		"4.2.4",
		"4.2.5",
		"4.2.6",
		"4.2.7",
		"4.2.8",
		"4.2.9",
		"4.2.10",
		"4.2.11",
		"4.2.12"
	],
	"72.0.3626.52": [
		"5.0.0-beta.1",
		"5.0.0-beta.2"
	],
	"73.0.3683.27": [
		"5.0.0-beta.3"
	],
	"73.0.3683.54": [
		"5.0.0-beta.4"
	],
	"73.0.3683.61": [
		"5.0.0-beta.5"
	],
	"73.0.3683.84": [
		"5.0.0-beta.6"
	],
	"73.0.3683.94": [
		"5.0.0-beta.7"
	],
	"73.0.3683.104": [
		"5.0.0-beta.8"
	],
	"73.0.3683.117": [
		"5.0.0-beta.9"
	],
	"70.0.3538.110": [
		"5.0.0-nightly.20190107"
	],
	"71.0.3578.98": [
		"5.0.0-nightly.20190121",
		"5.0.0-nightly.20190122"
	],
	"73.0.3683.119": [
		"5.0.0"
	],
	"73.0.3683.121": [
		"5.0.1",
		"5.0.2",
		"5.0.3",
		"5.0.4",
		"5.0.5",
		"5.0.6",
		"5.0.7",
		"5.0.8",
		"5.0.9",
		"5.0.10",
		"5.0.11",
		"5.0.12",
		"5.0.13"
	],
	"76.0.3774.1": [
		"6.0.0-beta.1"
	],
	"76.0.3783.1": [
		"6.0.0-beta.2",
		"6.0.0-beta.3",
		"6.0.0-beta.4"
	],
	"76.0.3805.4": [
		"6.0.0-beta.5"
	],
	"76.0.3809.3": [
		"6.0.0-beta.6"
	],
	"76.0.3809.22": [
		"6.0.0-beta.7"
	],
	"76.0.3809.26": [
		"6.0.0-beta.8",
		"6.0.0-beta.9"
	],
	"76.0.3809.37": [
		"6.0.0-beta.10"
	],
	"76.0.3809.42": [
		"6.0.0-beta.11"
	],
	"76.0.3809.54": [
		"6.0.0-beta.12"
	],
	"76.0.3809.60": [
		"6.0.0-beta.13"
	],
	"76.0.3809.68": [
		"6.0.0-beta.14"
	],
	"76.0.3809.74": [
		"6.0.0-beta.15"
	],
	"72.0.3626.107": [
		"6.0.0-nightly.20190212"
	],
	"72.0.3626.110": [
		"6.0.0-nightly.20190213"
	],
	"74.0.3724.8": [
		"6.0.0-nightly.20190311"
	],
	"76.0.3809.88": [
		"6.0.0"
	],
	"76.0.3809.102": [
		"6.0.1"
	],
	"76.0.3809.110": [
		"6.0.2"
	],
	"76.0.3809.126": [
		"6.0.3"
	],
	"76.0.3809.131": [
		"6.0.4"
	],
	"76.0.3809.136": [
		"6.0.5"
	],
	"76.0.3809.138": [
		"6.0.6"
	],
	"76.0.3809.139": [
		"6.0.7"
	],
	"76.0.3809.146": [
		"6.0.8",
		"6.0.9",
		"6.0.10",
		"6.0.11",
		"6.0.12",
		"6.1.0",
		"6.1.1",
		"6.1.2",
		"6.1.3",
		"6.1.4",
		"6.1.5",
		"6.1.6",
		"6.1.7",
		"6.1.8",
		"6.1.9",
		"6.1.10",
		"6.1.11",
		"6.1.12"
	],
	"78.0.3866.0": [
		"7.0.0-beta.1",
		"7.0.0-beta.2",
		"7.0.0-beta.3",
		"7.0.0-nightly.20190727",
		"7.0.0-nightly.20190728",
		"7.0.0-nightly.20190729",
		"7.0.0-nightly.20190730",
		"7.0.0-nightly.20190731",
		"8.0.0-nightly.20190801",
		"8.0.0-nightly.20190802"
	],
	"78.0.3896.6": [
		"7.0.0-beta.4"
	],
	"78.0.3905.1": [
		"7.0.0-beta.5",
		"7.0.0-beta.6",
		"7.0.0-beta.7",
		"7.0.0"
	],
	"76.0.3784.0": [
		"7.0.0-nightly.20190521"
	],
	"76.0.3806.0": [
		"7.0.0-nightly.20190529",
		"7.0.0-nightly.20190530",
		"7.0.0-nightly.20190531",
		"7.0.0-nightly.20190602",
		"7.0.0-nightly.20190603"
	],
	"77.0.3814.0": [
		"7.0.0-nightly.20190604"
	],
	"77.0.3815.0": [
		"7.0.0-nightly.20190605",
		"7.0.0-nightly.20190606",
		"7.0.0-nightly.20190607",
		"7.0.0-nightly.20190608",
		"7.0.0-nightly.20190609",
		"7.0.0-nightly.20190611",
		"7.0.0-nightly.20190612",
		"7.0.0-nightly.20190613",
		"7.0.0-nightly.20190615",
		"7.0.0-nightly.20190616",
		"7.0.0-nightly.20190618",
		"7.0.0-nightly.20190619",
		"7.0.0-nightly.20190622",
		"7.0.0-nightly.20190623",
		"7.0.0-nightly.20190624",
		"7.0.0-nightly.20190627",
		"7.0.0-nightly.20190629",
		"7.0.0-nightly.20190630",
		"7.0.0-nightly.20190701",
		"7.0.0-nightly.20190702"
	],
	"77.0.3843.0": [
		"7.0.0-nightly.20190704",
		"7.0.0-nightly.20190705"
	],
	"77.0.3848.0": [
		"7.0.0-nightly.20190719",
		"7.0.0-nightly.20190720",
		"7.0.0-nightly.20190721"
	],
	"77.0.3864.0": [
		"7.0.0-nightly.20190726"
	],
	"78.0.3904.92": [
		"7.0.1"
	],
	"78.0.3904.94": [
		"7.1.0"
	],
	"78.0.3904.99": [
		"7.1.1"
	],
	"78.0.3904.113": [
		"7.1.2"
	],
	"78.0.3904.126": [
		"7.1.3"
	],
	"78.0.3904.130": [
		"7.1.4",
		"7.1.5",
		"7.1.6",
		"7.1.7",
		"7.1.8",
		"7.1.9",
		"7.1.10",
		"7.1.11",
		"7.1.12",
		"7.1.13",
		"7.1.14",
		"7.2.0",
		"7.2.1",
		"7.2.2",
		"7.2.3",
		"7.2.4",
		"7.3.0",
		"7.3.1",
		"7.3.2"
	],
	"79.0.3931.0": [
		"8.0.0-beta.1",
		"8.0.0-beta.2",
		"8.0.0-nightly.20191019",
		"8.0.0-nightly.20191020",
		"8.0.0-nightly.20191021",
		"8.0.0-nightly.20191023"
	],
	"80.0.3955.0": [
		"8.0.0-beta.3",
		"8.0.0-beta.4"
	],
	"80.0.3987.14": [
		"8.0.0-beta.5"
	],
	"80.0.3987.51": [
		"8.0.0-beta.6"
	],
	"80.0.3987.59": [
		"8.0.0-beta.7"
	],
	"80.0.3987.75": [
		"8.0.0-beta.8",
		"8.0.0-beta.9"
	],
	"78.0.3871.0": [
		"8.0.0-nightly.20190803",
		"8.0.0-nightly.20190806",
		"8.0.0-nightly.20190807",
		"8.0.0-nightly.20190808",
		"8.0.0-nightly.20190809",
		"8.0.0-nightly.20190810",
		"8.0.0-nightly.20190811",
		"8.0.0-nightly.20190812",
		"8.0.0-nightly.20190813",
		"8.0.0-nightly.20190814",
		"8.0.0-nightly.20190815"
	],
	"78.0.3881.0": [
		"8.0.0-nightly.20190816",
		"8.0.0-nightly.20190817",
		"8.0.0-nightly.20190818",
		"8.0.0-nightly.20190819",
		"8.0.0-nightly.20190820"
	],
	"78.0.3892.0": [
		"8.0.0-nightly.20190824",
		"8.0.0-nightly.20190825",
		"8.0.0-nightly.20190827",
		"8.0.0-nightly.20190828",
		"8.0.0-nightly.20190830",
		"8.0.0-nightly.20190901",
		"8.0.0-nightly.20190902",
		"8.0.0-nightly.20190907",
		"8.0.0-nightly.20190909",
		"8.0.0-nightly.20190910",
		"8.0.0-nightly.20190911",
		"8.0.0-nightly.20190913",
		"8.0.0-nightly.20190914",
		"8.0.0-nightly.20190915",
		"8.0.0-nightly.20190917"
	],
	"79.0.3915.0": [
		"8.0.0-nightly.20190919",
		"8.0.0-nightly.20190920"
	],
	"79.0.3919.0": [
		"8.0.0-nightly.20190923",
		"8.0.0-nightly.20190924",
		"8.0.0-nightly.20190926",
		"8.0.0-nightly.20190929",
		"8.0.0-nightly.20190930",
		"8.0.0-nightly.20191001",
		"8.0.0-nightly.20191004",
		"8.0.0-nightly.20191005",
		"8.0.0-nightly.20191006",
		"8.0.0-nightly.20191009",
		"8.0.0-nightly.20191011",
		"8.0.0-nightly.20191012",
		"8.0.0-nightly.20191017"
	],
	"80.0.3952.0": [
		"8.0.0-nightly.20191101",
		"8.0.0-nightly.20191105"
	],
	"80.0.3987.86": [
		"8.0.0",
		"8.0.1",
		"8.0.2"
	],
	"80.0.3987.134": [
		"8.0.3"
	],
	"80.0.3987.137": [
		"8.1.0"
	],
	"80.0.3987.141": [
		"8.1.1"
	],
	"80.0.3987.158": [
		"8.2.0"
	],
	"80.0.3987.163": [
		"8.2.1",
		"8.2.2",
		"8.2.3"
	],
	"80.0.3987.165": [
		"8.2.4",
		"8.2.5",
		"8.3.0",
		"8.3.1",
		"8.3.2",
		"8.3.3",
		"8.3.4",
		"8.4.0"
	],
	"82.0.4048.0": [
		"9.0.0-beta.1",
		"9.0.0-beta.2",
		"9.0.0-beta.3",
		"9.0.0-beta.4",
		"9.0.0-beta.5"
	],
	"82.0.4058.2": [
		"9.0.0-beta.6",
		"9.0.0-beta.7",
		"9.0.0-beta.9"
	],
	"82.0.4085.10": [
		"9.0.0-beta.10"
	],
	"82.0.4085.14": [
		"9.0.0-beta.12",
		"9.0.0-beta.13"
	],
	"82.0.4085.27": [
		"9.0.0-beta.14"
	],
	"83.0.4102.3": [
		"9.0.0-beta.15",
		"9.0.0-beta.16"
	],
	"83.0.4103.14": [
		"9.0.0-beta.17"
	],
	"83.0.4103.16": [
		"9.0.0-beta.18"
	],
	"83.0.4103.24": [
		"9.0.0-beta.19"
	],
	"83.0.4103.26": [
		"9.0.0-beta.20",
		"9.0.0-beta.21"
	],
	"83.0.4103.34": [
		"9.0.0-beta.22"
	],
	"83.0.4103.44": [
		"9.0.0-beta.23"
	],
	"83.0.4103.45": [
		"9.0.0-beta.24"
	],
	"80.0.3954.0": [
		"9.0.0-nightly.20191121",
		"9.0.0-nightly.20191122",
		"9.0.0-nightly.20191123",
		"9.0.0-nightly.20191124",
		"9.0.0-nightly.20191129",
		"9.0.0-nightly.20191130",
		"9.0.0-nightly.20191201",
		"9.0.0-nightly.20191202",
		"9.0.0-nightly.20191203",
		"9.0.0-nightly.20191204",
		"9.0.0-nightly.20191210"
	],
	"81.0.3994.0": [
		"9.0.0-nightly.20191220",
		"9.0.0-nightly.20191221",
		"9.0.0-nightly.20191222",
		"9.0.0-nightly.20191223",
		"9.0.0-nightly.20191224",
		"9.0.0-nightly.20191225",
		"9.0.0-nightly.20191226",
		"9.0.0-nightly.20191228",
		"9.0.0-nightly.20191229",
		"9.0.0-nightly.20191230",
		"9.0.0-nightly.20191231",
		"9.0.0-nightly.20200101",
		"9.0.0-nightly.20200103",
		"9.0.0-nightly.20200104",
		"9.0.0-nightly.20200105",
		"9.0.0-nightly.20200106",
		"9.0.0-nightly.20200108",
		"9.0.0-nightly.20200109",
		"9.0.0-nightly.20200110",
		"9.0.0-nightly.20200111",
		"9.0.0-nightly.20200113",
		"9.0.0-nightly.20200115",
		"9.0.0-nightly.20200116",
		"9.0.0-nightly.20200117"
	],
	"81.0.4030.0": [
		"9.0.0-nightly.20200119",
		"9.0.0-nightly.20200121"
	],
	"83.0.4103.64": [
		"9.0.0"
	],
	"83.0.4103.94": [
		"9.0.1",
		"9.0.2"
	],
	"83.0.4103.100": [
		"9.0.3"
	],
	"83.0.4103.104": [
		"9.0.4"
	],
	"83.0.4103.119": [
		"9.0.5"
	],
	"83.0.4103.122": [
		"9.1.0"
	],
	"84.0.4129.0": [
		"10.0.0-beta.1",
		"10.0.0-beta.2",
		"10.0.0-nightly.20200501",
		"10.0.0-nightly.20200504",
		"10.0.0-nightly.20200505",
		"10.0.0-nightly.20200506",
		"10.0.0-nightly.20200507",
		"10.0.0-nightly.20200508",
		"10.0.0-nightly.20200511",
		"10.0.0-nightly.20200512",
		"10.0.0-nightly.20200513",
		"10.0.0-nightly.20200514",
		"10.0.0-nightly.20200515",
		"10.0.0-nightly.20200518",
		"10.0.0-nightly.20200519",
		"10.0.0-nightly.20200520",
		"10.0.0-nightly.20200521",
		"11.0.0-nightly.20200525",
		"11.0.0-nightly.20200526"
	],
	"85.0.4161.2": [
		"10.0.0-beta.3",
		"10.0.0-beta.4"
	],
	"85.0.4181.1": [
		"10.0.0-beta.8",
		"10.0.0-beta.9"
	],
	"85.0.4183.19": [
		"10.0.0-beta.10"
	],
	"85.0.4183.20": [
		"10.0.0-beta.11"
	],
	"85.0.4183.26": [
		"10.0.0-beta.12"
	],
	"82.0.4050.0": [
		"10.0.0-nightly.20200209",
		"10.0.0-nightly.20200210",
		"10.0.0-nightly.20200211",
		"10.0.0-nightly.20200216",
		"10.0.0-nightly.20200217",
		"10.0.0-nightly.20200218",
		"10.0.0-nightly.20200221",
		"10.0.0-nightly.20200222",
		"10.0.0-nightly.20200223",
		"10.0.0-nightly.20200226",
		"10.0.0-nightly.20200303"
	],
	"82.0.4076.0": [
		"10.0.0-nightly.20200304",
		"10.0.0-nightly.20200305",
		"10.0.0-nightly.20200306",
		"10.0.0-nightly.20200309",
		"10.0.0-nightly.20200310"
	],
	"82.0.4083.0": [
		"10.0.0-nightly.20200311"
	],
	"83.0.4086.0": [
		"10.0.0-nightly.20200316"
	],
	"83.0.4087.0": [
		"10.0.0-nightly.20200317",
		"10.0.0-nightly.20200318",
		"10.0.0-nightly.20200320",
		"10.0.0-nightly.20200323",
		"10.0.0-nightly.20200324",
		"10.0.0-nightly.20200325",
		"10.0.0-nightly.20200326",
		"10.0.0-nightly.20200327",
		"10.0.0-nightly.20200330",
		"10.0.0-nightly.20200331",
		"10.0.0-nightly.20200401",
		"10.0.0-nightly.20200402",
		"10.0.0-nightly.20200403",
		"10.0.0-nightly.20200406"
	],
	"83.0.4095.0": [
		"10.0.0-nightly.20200408",
		"10.0.0-nightly.20200410",
		"10.0.0-nightly.20200413"
	],
	"84.0.4114.0": [
		"10.0.0-nightly.20200414"
	],
	"84.0.4115.0": [
		"10.0.0-nightly.20200415",
		"10.0.0-nightly.20200416",
		"10.0.0-nightly.20200417"
	],
	"84.0.4121.0": [
		"10.0.0-nightly.20200422",
		"10.0.0-nightly.20200423"
	],
	"84.0.4125.0": [
		"10.0.0-nightly.20200427",
		"10.0.0-nightly.20200428",
		"10.0.0-nightly.20200429",
		"10.0.0-nightly.20200430"
	],
	"85.0.4156.0": [
		"11.0.0-nightly.20200529"
	],
	"85.0.4162.0": [
		"11.0.0-nightly.20200602",
		"11.0.0-nightly.20200603",
		"11.0.0-nightly.20200604",
		"11.0.0-nightly.20200609",
		"11.0.0-nightly.20200610",
		"11.0.0-nightly.20200611",
		"11.0.0-nightly.20200615",
		"11.0.0-nightly.20200616",
		"11.0.0-nightly.20200617",
		"11.0.0-nightly.20200618",
		"11.0.0-nightly.20200619"
	],
	"85.0.4179.0": [
		"11.0.0-nightly.20200701",
		"11.0.0-nightly.20200702",
		"11.0.0-nightly.20200703",
		"11.0.0-nightly.20200706",
		"11.0.0-nightly.20200707",
		"11.0.0-nightly.20200708",
		"11.0.0-nightly.20200709"
	],
	"86.0.4203.0": [
		"11.0.0-nightly.20200716"
	]
};